@@ -17,13 +17,17 @@
 
 #ifdef HAVE_DYNINST
 
-extern int liveness(std::string executable,
+extern int liveness(systemtap_session& s,
+		    target_symbol *e,
+		    std::string executable,
 		    Dwarf_Addr location,
 		    location_context ctx);
 
+extern void flush_analysis_caches();
 #else
 
-#define liveness(executable, location, var) (0)
+#define liveness(session, target, executable, location, var) (0)
+#define flush_analysis_caches() {/* nothing to do */}
 
 #endif // HAVE_DYNINST
 #endif // ANALYSIS_H
