@@ -15,11 +15,10 @@ int compile_pass (systemtap_session& s);
 int uprobes_pass (systemtap_session& s);
 
 std::vector<std::string> make_run_command (systemtap_session& s,
-                                           const std::string& module="",
+                                           const std::string& remotedir="",
                                            const std::string& version=VERSION);
 
-int make_tracequery(systemtap_session& s, std::string& name,
-                    const std::vector<std::string>& headers);
+std::map<std::string,std::string> make_tracequeries(systemtap_session& s, const std::map<std::string,std::string>& contents);
 int make_typequery(systemtap_session& s, std::string& module);
 
 #endif // BUILDRUN_H
