@@ -15,6 +15,7 @@ struct option stap_long_options[] = {
   { "skip-badvars",                no_argument,       NULL, LONG_OPT_SKIP_BADVARS },
   { "vp",                          required_argument, NULL, LONG_OPT_VERBOSE_PASS },
   { "unprivileged",                no_argument,       NULL, LONG_OPT_UNPRIVILEGED },
+  { "build-as",                    optional_argument, NULL, LONG_OPT_BUILD_AS },
   { "client-options",              no_argument,       NULL, LONG_OPT_CLIENT_OPTIONS },
   { "help",                        no_argument,       NULL, LONG_OPT_HELP },
   { "disable-cache",               no_argument,       NULL, LONG_OPT_DISABLE_CACHE },
@@ -64,5 +65,6 @@ struct option stap_long_options[] = {
   { "interactive",                 no_argument,       NULL, LONG_OPT_INTERACTIVE},
   { "example",                     no_argument,       NULL, LONG_OPT_RUN_EXAMPLE},
   { "no-global-var-display",       no_argument,       NULL, LONG_OPT_NO_GLOBAL_VAR_DISPLAY},
+  { "language-server",             no_argument,       NULL, LONG_OPT_LANGUAGE_SERVER},
   { NULL, 0, NULL, 0 }
 };
