@@ -20,6 +20,7 @@ enum {
   LONG_OPT_VERBOSE_PASS = 256,
   LONG_OPT_SKIP_BADVARS,
   LONG_OPT_UNPRIVILEGED,
+  LONG_OPT_BUILD_AS,
   LONG_OPT_CLIENT_OPTIONS,
   LONG_OPT_HELP,
   LONG_OPT_DISABLE_CACHE,
@@ -32,6 +33,7 @@ enum {
   LONG_OPT_TRUST_SERVERS,
   LONG_OPT_USE_HTTP_SERVER,
   LONG_OPT_ALL_MODULES,
+  LONG_OPT_SIGN_MODULE,
   LONG_OPT_REMOTE,
   LONG_OPT_CHECK_VERSION,
   LONG_OPT_USE_SERVER_ON_ERROR,
@@ -67,6 +69,7 @@ enum {
   LONG_OPT_INTERACTIVE,
   LONG_OPT_RUN_EXAMPLE,
   LONG_OPT_NO_GLOBAL_VAR_DISPLAY,
+  LONG_OPT_LANGUAGE_SERVER,
 };
 
 // NB: when adding new options, consider very carefully whether they
