@@ -159,10 +159,10 @@ cat<<EOF
 EOF
 
 # Detect git tool (should work with old and new git versions)
-git_found=yes
-if [ "x$GIT" = "xgit" ] && [ x`which $GIT 2>/dev/null` = "x" ]; then
-    git_found="'$GIT' not found"
-    break
+if type $GIT >/dev/null 2>&1; then
+    git_found=yes
+else
+    git_found="'$GIT' not found"   
 fi
 # If git_found=yes, we can now use $() substitutions (as git does). Hooray!
 
