@@ -30,6 +30,8 @@ static /*const*/ char* get_java_string(JNIEnv *env, jobject _string)
  */
 static /*const*/ char* get_java_tostring(JNIEnv *env, jobject _obj)
 {
+  if ((*env)->IsSameObject(env, _obj, NULL))
+    return strdup("(null)"); /* need a real string to avoid user_string_warn getting upset */
   jclass class_arg = (*env)->GetObjectClass(env, _obj);
   jmethodID getMsgMeth = (*env)->GetMethodID(env, class_arg, "toString", "()Ljava/lang/String;");
   jstring obj = (jstring)(*env)->CallObjectMethod(env, _obj, getMsgMeth);
@@ -43,6 +45,11 @@ static /*const*/ char* get_java_tostring(JNIEnv *env, jobject _obj)
 
 static int64_t determine_java_type(JNIEnv *env, jobject _arg, _Bool *need_free)
 {
+  if ((*env)->IsSameObject(env, _arg, NULL)) {
+    *need_free = 1;
+    return (int64_t) (uintptr_t) strdup("(null)"); /* need a real string to avoid user_string_warn getting upset */
+  }
+
   jclass class_arg = (*env)->GetObjectClass(env, _arg);
   jfieldID fidNumber = 0;
   *need_free = false;
@@ -80,7 +87,7 @@ static int64_t determine_java_type(JNIEnv *env, jobject _arg, _Bool *need_free)
   (*env)->ExceptionClear(env);
   /* Not a simple numeric scalar. Caller must free(). */
   *need_free = true;
-  return (int64_t) get_java_tostring(env, _arg);
+  return (int64_t) (uintptr_t) get_java_tostring(env, _arg);
 }
 
 static char *alloc_sargs(int64_t *sargs, _Bool *sfree, JNIEnv *env,
@@ -99,7 +106,7 @@ static void free_sargs(char *rulename, int64_t *sargs, _Bool *sfree, int num)
   int i;
   for (i = 0;i < num; i++)
     if (sfree[i])
-      free((void *) sargs[i]);
+      free((void *) (uintptr_t) sargs[i]);
   free(rulename);
 }
 
