@@ -15,7 +15,7 @@
 #include "cscommon.h"
 #include "csclient.h"
 #include "client-nss.h"
-#include "util.h"
+#include "staputil.h"
 #include "stap-probe.h"
 
 #include <sys/times.h>
@@ -320,6 +320,10 @@ nss_trustNewServer (CERTCertificate *serverCert)
   secStatus = PK11_ImportCert(slot, serverCert, CK_INVALID_HANDLE, nickname, PR_FALSE);
   if (secStatus != SECSuccess)
     goto done;
+
+  if (PK11_NeedUserInit(slot)) {
+    PK11_InitPin(slot, (char*)NULL, "");
+  }
   
   /* Make it a trusted peer.  */
   trust = (CERTCertTrust *)PORT_ZAlloc(sizeof(CERTCertTrust));
