@@ -1,6 +1,6 @@
 /* -*- linux-c -*- 
  * Map Runtime Functions
- * Copyright (C) 2012 Red Hat Inc.
+ * Copyright (C) 2012-2016 Red Hat Inc.
  *
  * This file is part of systemtap, and is free software.  You can
  * redistribute it and/or modify it under the terms of the GNU General
@@ -13,43 +13,12 @@
 
 #include <pthread.h>
 
-#ifdef NEED_MAP_LOCKS
-#define MAP_LOCK(m)	pthread_mutex_lock(&(m)->lock)
-#define MAP_UNLOCK(m)	pthread_mutex_unlock(&(m)->lock)
-#else
-#define MAP_LOCK(sd)	do {} while (0)
-#define MAP_UNLOCK(sd)	do {} while (0)
-#endif
-
-/* Note that pthread_mutex_trylock()'s return value is opposite of the
- * kernel's spin_trylock(), so we invert the return value of
- * pthread_mutex_trylock(). */
-#define MAP_TRYLOCK(m)	(!pthread_mutex_trylock(&(m)->lock))
-
 #define MAP_GET_CPU()	STAT_GET_CPU()
 #define MAP_PUT_CPU()	STAT_PUT_CPU()
 
-static int _stp_map_initialize_lock(MAP m)
-{
-#ifdef NEED_MAP_LOCKS
-	int rc;
-
-	if ((rc = stp_pthread_mutex_init_shared(&m->lock)) != 0) {
-		_stp_error("Couldn't initialize map mutex: %d\n", rc);
-		return rc;
-	}
-#endif
-	return 0;
-}
-
-static void _stp_map_destroy_lock(MAP m)
-{
-#ifdef NEED_MAP_LOCKS
-	(void)pthread_mutex_destroy(&m->lock);
-#endif
-}
-
 struct pmap {
+	int bit_shift;    /* scale factor for integer arithmetic */
+	int stat_ops;     /* related statistical operators */
 	offptr_t oagg;    /* aggregation map */
 	offptr_t omap[];  /* per-cpu maps */
 };
@@ -81,11 +50,6 @@ static inline void _stp_pmap_set_map(PMAP p, MAP m, unsigned cpu)
 
 static void __stp_map_del(MAP map)
 {
-	if (map == NULL)
-		return;
-
-	/* The lock is the only thing to clean up.  */
-	_stp_map_destroy_lock(map);
 }
 
 
@@ -97,9 +61,6 @@ static void __stp_map_del(MAP map)
 
 static void _stp_map_del(MAP map)
 {
-	if (map == NULL)
-		return;
-
 	__stp_map_del(map);
 	_stp_shm_free(map);
 }
@@ -108,9 +69,6 @@ static void _stp_pmap_del(PMAP pmap)
 {
 	int i;
 
-	if (pmap == NULL)
-		return;
-
 	/* The pmap is one giant allocation, so do only
 	 * the basic cleanup for each map.  */
 	for_each_possible_cpu(i)
@@ -121,16 +79,17 @@ static void _stp_pmap_del(PMAP pmap)
 
 
 static int
-_stp_map_init(MAP m, unsigned max_entries, int wrap, int node_size)
+_stp_map_init(MAP m, unsigned max_entries, unsigned hash_table_mask, int wrap, int node_size)
 {
 	unsigned i;
 
-	/* The node memory is allocated right after the map itself.  */
-	void *node_mem = m + 1;
+	/* The node memory is allocated right after the map (incl. the hash table).  */
+	void *node_mem = (void*)(m + 1) + sizeof(struct mhlist_head)*(hash_table_mask+1);
 
 	INIT_MLIST_HEAD(&m->pool);
 	INIT_MLIST_HEAD(&m->head);
-	for (i = 0; i < HASH_TABLE_SIZE; i++)
+        m->hash_table_mask = hash_table_mask;
+	for (i = 0; i <= m->hash_table_mask; i++)
 		INIT_MHLIST_HEAD(&m->hashes[i]);
 
 	m->maxnum = max_entries;
@@ -142,9 +101,6 @@ _stp_map_init(MAP m, unsigned max_entries, int wrap, int node_size)
 		INIT_MHLIST_NODE(&node->hnode);
 	}
 
-	if (_stp_map_initialize_lock(m) != 0)
-		return -1;
-
 	return 0;
 }
 
@@ -166,12 +122,15 @@ _stp_map_new(unsigned max_entries, int wrap, int node_size,
 
 	/* NB: Allocate the map in one big chuck.
 	 * (See _stp_pmap_new for more explanation) */
-	size_t map_size = sizeof(struct map_root) + node_size * max_entries;
+        unsigned hash_table_mask = HASHTABLESIZE(max_entries)-1; /* usable as bitmask */
+	size_t map_size = sizeof(struct map_root)
+                + sizeof(struct mhlist_head) * (hash_table_mask+1)
+                + node_size * max_entries;
 	m = _stp_shm_zalloc(map_size);
 	if (m == NULL)
 		return NULL;
 
-	if (_stp_map_init(m, max_entries, wrap, node_size)) {
+	if (_stp_map_init(m, max_entries, hash_table_mask, wrap, node_size)) {
 		_stp_map_del(m);
 		return NULL;
 	}
@@ -185,6 +144,7 @@ _stp_pmap_new(unsigned max_entries, int wrap, int node_size)
 	MAP m;
 	PMAP pmap;
 	void *map_mem;
+        unsigned hash_table_mask = HASHTABLESIZE(max_entries)-1; /* usable as bitmask */
 
 	/* Allocate the pmap in one big chuck.
 	 *
@@ -198,11 +158,11 @@ _stp_pmap_new(unsigned max_entries, int wrap, int node_size)
 	 * cause it to move later, that's ok.
 	 */
 
-	size_t map_size = sizeof(struct map_root) + node_size * max_entries;
-
+	size_t map_size = sizeof(struct map_root)
+                + sizeof(struct mhlist_head) * (hash_table_mask+1)
+                + node_size * max_entries;
 	size_t pmap_size = sizeof(struct pmap) +
 		sizeof(offptr_t) * _stp_runtime_num_contexts;
-
 	size_t total_size = pmap_size +
 		map_size * (_stp_runtime_num_contexts + 1);
 
@@ -218,7 +178,7 @@ _stp_pmap_new(unsigned max_entries, int wrap, int node_size)
 	/* Initialize the per-cpu maps.  */
 	for_each_possible_cpu(i) {
 		m = map_mem;
-		if (_stp_map_init(m, max_entries, wrap, node_size) != 0)
+		if (_stp_map_init(m, max_entries, hash_table_mask, wrap, node_size) != 0)
 			goto err;
                 _stp_pmap_set_map(pmap, m, i);
 		map_mem += map_size;
@@ -226,7 +186,7 @@ _stp_pmap_new(unsigned max_entries, int wrap, int node_size)
 
 	/* Initialize the aggregate map.  */
 	m = map_mem;
-	if (_stp_map_init(m, max_entries, wrap, node_size) != 0)
+	if (_stp_map_init(m, max_entries, hash_table_mask, wrap, node_size) != 0)
 		goto err;
         _stp_pmap_set_agg(pmap, m);
 
