@@ -1,6 +1,6 @@
 /* -*- linux-c -*- 
  * Syscall compatibility defines.
- * Copyright (C) 2013-2018 Red Hat Inc.
+ * Copyright (C) 2013-2019 Red Hat Inc.
  *
  * This file is part of systemtap, and is free software.  You can
  * redistribute it and/or modify it under the terms of the GNU General
@@ -31,33 +31,66 @@
 #ifndef __NR__newselect
 #define __NR__newselect (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_access
+#define __NR_access (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_accept
 #define __NR_accept (__NR_syscall_max + 1)
 #endif
 #ifndef __NR_accept4
 #define __NR_accept4 (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_bdflush
+#define __NR_bdflush (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_bind
 #define __NR_bind (__NR_syscall_max + 1)
 #endif
 #ifndef __NR_bpf
 #define __NR_bpf (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_chmod
+#define __NR_chmod (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_chown
+#define __NR_chown (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_chown32
+#define __NR_chown32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_compat_bdflush
+#define __NR_compat_bdflush (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_connect
 #define __NR_connect (__NR_syscall_max + 1)
 #endif
 #ifndef __NR_copy_file_range
 #define __NR_copy_file_range (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_creat
+#define __NR_creat (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_dup2
+#define __NR_dup2 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_epoll_wait
 #define __NR_epoll_wait (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_eventfd
+#define __NR_eventfd (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_execveat
 #define __NR_execveat (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_faccessat2
+#define __NR_faccessat2 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_fadvise64_64
 #define __NR_fadvise64_64 (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_fchown32
+#define __NR_fchown32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_fcntl64
 #define __NR_fcntl64 (__NR_syscall_max + 1)
 #endif
@@ -85,24 +118,54 @@
 #ifndef __NR_getcpu
 #define __NR_getcpu (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_getdents
+#define __NR_getdents (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_getegid32
+#define __NR_getegid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_geteuid32
+#define __NR_geteuid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_getgid32
+#define __NR_getgid32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_getgroups32
 #define __NR_getgroups32 (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_get_mempolicy
+#define __NR_get_mempolicy (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_getpeername
 #define __NR_getpeername (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_getpgrp
+#define __NR_getpgrp (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_getrandom
 #define __NR_getrandom (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_getresgid32
+#define __NR_getresgid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_getresuid32
+#define __NR_getresuid32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_getsockname
 #define __NR_getsockname (__NR_syscall_max + 1)
 #endif
 #ifndef __NR_getsockopt
 #define __NR_getsockopt (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_getuid32
+#define __NR_getuid32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_io_pgetevents
 #define __NR_io_pgetevents (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_inotify_init
+#define __NR_inotify_init (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_ipc
 #define __NR_ipc (__NR_syscall_max + 1)
 #endif
@@ -112,15 +175,39 @@
 #ifndef __NR_kexec_file_load
 #define __NR_kexec_file_load (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_lchown
+#define __NR_lchown (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_lchown32
+#define __NR_lchown32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_link
+#define __NR_link (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_listen
 #define __NR_listen (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_lstat
+#define __NR_lstat (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_lstat64
 #define __NR_lstat64 (__NR_syscall_max + 1)
 #endif
 #ifndef __NR_membarrier
 #define __NR_membarrier (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_memfd_secret
+#define __NR_memfd_secret (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_migrate_pages
+#define __NR_migrate_pages (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_mkdir
+#define __NR_mkdir (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_mknod
+#define __NR_mknod (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_mlock2
 #define __NR_mlock2 (__NR_syscall_max + 1)
 #endif
@@ -166,6 +253,15 @@
 #ifndef __NR_open
 #define __NR_open (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_pause
+#define __NR_pause (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_pipe
+#define __NR_pipe (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_poll
+#define __NR_poll (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_preadv2
 #define __NR_preadv2 (__NR_syscall_max + 1)
 #endif
@@ -178,6 +274,9 @@
 #ifndef __NR_readdir
 #define __NR_readdir (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_readlink
+#define __NR_readlink (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_recv
 #define __NR_recv (__NR_syscall_max + 1)
 #endif
@@ -187,12 +286,30 @@
 #ifndef __NR_recvmsg
 #define __NR_recvmsg (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_rename
+#define __NR_rename (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_renameat2
 #define __NR_renameat2 (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_rmdir
+#define __NR_rmdir (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_rseq
 #define __NR_rseq (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_select
+#define __NR_select (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_semctl
+#define __NR_semctl (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_semget
+#define __NR_semget (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_semop
+#define __NR_semop (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_semtimedop
 #define __NR_semtimedop (__NR_syscall_max + 1)
 #endif
@@ -208,18 +325,54 @@
 #ifndef __NR_sendto
 #define __NR_sendto (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_setfsgid32
+#define __NR_setfsgid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_setfsuid32
+#define __NR_setfsuid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_setgid32
+#define __NR_setgid32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_setgroups32
 #define __NR_setgroups32 (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_set_mempolicy
+#define __NR_set_mempolicy (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_setregid32
+#define __NR_setregid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_setresgid32
+#define __NR_setresgid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_setresuid32
+#define __NR_setresuid32 (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_setreuid32
+#define __NR_setreuid32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_setsockopt
 #define __NR_setsockopt (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_setuid32
+#define __NR_setuid32 (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_sgetmask
 #define __NR_sgetmask (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_shmat
+#define __NR_shmat (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_shmctl
 #define __NR_shmctl (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_shmdt
+#define __NR_shmdt (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_shmget
+#define __NR_shmget (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_shutdown
 #define __NR_shutdown (__NR_syscall_max + 1)
 #endif
@@ -250,6 +403,9 @@
 #ifndef __NR_ssetmask
 #define __NR_ssetmask (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_stat
+#define __NR_stat (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_stat64
 #define __NR_stat64 (__NR_syscall_max + 1)
 #endif
@@ -262,6 +418,18 @@
 #ifndef __NR_stime
 #define __NR_stime (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_symlink
+#define __NR_symlink (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_sync_file_range
+#define __NR_sync_file_range (__NR_syscall_max + 1)
+#endif
+#ifndef __NR__sysctl
+#define __NR__sysctl (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_sysfs
+#define __NR_sysfs (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_truncate
 #define __NR_truncate (__NR_syscall_max + 1)
 #endif
@@ -274,9 +442,54 @@
 #ifndef __NR_umount
 #define __NR_umount (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_unlink
+#define __NR_unlink (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_uselib
+#define __NR_uselib (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_userfaultfd
+#define __NR_userfaultfd (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_ustat
+#define __NR_ustat (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_utimes
+#define __NR_utimes (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_vfork
+#define __NR_vfork (__NR_syscall_max + 1)
+#endif
 #ifndef __NR_waitpid
 #define __NR_waitpid (__NR_syscall_max + 1)
 #endif
+#ifndef __NR_alarm
+#define __NR_alarm (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_ioperm
+#define __NR_ioperm (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_mbind
+#define __NR_mbind (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_modify_ldt
+#define __NR_modify_ldt (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_time
+#define __NR_time (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_utime
+#define __NR_utime (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_pkey_alloc
+#define __NR_pkey_alloc (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_pkey_free
+#define __NR_pkey_free (__NR_syscall_max + 1)
+#endif
+#ifndef __NR_pkey_mprotect
+#define __NR_pkey_mprotect (__NR_syscall_max + 1)
+#endif
 
 #if defined(__x86_64__)
 
@@ -309,12 +522,12 @@
 #ifndef __NR_ia32_arch_prctl
 #define __NR_ia32_arch_prctl 384
 #endif
-#ifndef __NR_ia32_brk
-#define __NR_ia32_brk 45
-#endif
 #ifndef __NR_ia32_bpf
 #define __NR_ia32_bpf 357
 #endif
+#ifndef __NR_ia32_brk
+#define __NR_ia32_brk 45
+#endif
 #ifndef __NR_ia32_capget
 #define __NR_ia32_capget 184
 #endif
@@ -339,12 +552,12 @@
 #ifndef __NR_ia32_clock_adjtime
 #define __NR_ia32_clock_adjtime 343
 #endif
-#ifndef __NR_ia32_clock_gettime
-#define __NR_ia32_clock_gettime 265
-#endif
 #ifndef __NR_ia32_clock_getres
 #define __NR_ia32_clock_getres 266
 #endif
+#ifndef __NR_ia32_clock_gettime
+#define __NR_ia32_clock_gettime 265
+#endif
 #ifndef __NR_ia32_clock_nanosleep
 #define __NR_ia32_clock_nanosleep 267
 #endif
@@ -359,7 +572,7 @@
 #endif
 #ifndef __NR_ia32_copy_file_range
 #define __NR_ia32_copy_file_range 377
-#endif 
+#endif
 #ifndef __NR_ia32_creat
 #define __NR_ia32_creat 8
 #endif
@@ -401,7 +614,7 @@
 #endif
 #ifndef __NR_ia32_execveat
 #define __NR_ia32_execveat 358
-#endif 
+#endif
 #ifndef __NR_ia32_exit
 #define __NR_ia32_exit 1
 #endif
@@ -411,6 +624,9 @@
 #ifndef __NR_ia32_faccessat
 #define __NR_ia32_faccessat 307
 #endif
+#ifndef __NR_ia32_faccessat2
+#define __NR_ia32_faccessat2 439
+#endif
 #ifndef __NR_ia32_fadvise64
 #define __NR_ia32_fadvise64 250
 #endif
@@ -431,7 +647,7 @@
 #endif
 #ifndef __NR_ia32_fchmod
 #define __NR_ia32_fchmod 94
-#endif 
+#endif
 #ifndef __NR_ia32_fchmodat
 #define __NR_ia32_fchmodat 306
 #endif
@@ -495,17 +711,17 @@
 #ifndef __NR_ia32_ftruncate
 #define __NR_ia32_ftruncate 93
 #endif
-#ifndef __NR_ia32_futimesat
-#define __NR_ia32_futimesat 299
-#endif
 #ifndef __NR_ia32_futex
 #define __NR_ia32_futex 240
 #endif
+#ifndef __NR_ia32_futimesat
+#define __NR_ia32_futimesat 299
+#endif
 #ifndef __NR_ia32_get_mempolicy
 #define __NR_ia32_get_mempolicy 275
 #endif
 #ifndef __NR_ia32_get_robust_list
-#define __NR_ia32_get_robust_list 311
+#define __NR_ia32_get_robust_list 312
 #endif
 #ifndef __NR_ia32_getcpu
 #define __NR_ia32_getcpu 318
@@ -553,7 +769,7 @@
 #define __NR_ia32_getpgrp 65
 #endif
 #ifndef __NR_ia32_getpid
-#define __NR_ia32_getpid 20 
+#define __NR_ia32_getpid 20
 #endif
 #ifndef __NR_ia32_getppid
 #define __NR_ia32_getppid 64
@@ -563,7 +779,7 @@
 #endif
 #ifndef __NR_ia32_getrandom
 #define __NR_ia32_getrandom 355
-#endif 
+#endif
 #ifndef __NR_ia32_getresgid
 #define __NR_ia32_getresgid 171
 #endif
@@ -581,7 +797,7 @@
 #endif
 #ifndef __NR_ia32_getrusage
 #define __NR_ia32_getrusage 77
-#endif 
+#endif
 #ifndef __NR_ia32_getsid
 #define __NR_ia32_getsid 147
 #endif
@@ -646,7 +862,7 @@
 #define __NR_ia32_ipc 117
 #endif
 #ifndef __NR_ia32_kcmp
-#define __NR_ia32_kcmp 349 
+#define __NR_ia32_kcmp 349
 #endif
 #ifndef __NR_ia32_kexec_file_load
 // x86_64 doesn't have kexec_file_load for 32-bit, just use
@@ -713,6 +929,9 @@
 #ifndef __NR_ia32_memfd_create
 #define __NR_ia32_memfd_create 356
 #endif
+#ifndef __NR_ia32_memfd_secret
+#define __NR_ia32_memfd_secret 447
+#endif
 #ifndef __NR_ia32_migrate_pages
 #define __NR_ia32_migrate_pages 294
 #endif
@@ -754,7 +973,7 @@
 #endif
 #ifndef __NR_ia32_mprotect
 #define __NR_ia32_mprotect 125
-#endif 
+#endif
 #ifndef __NR_ia32_mq_getsetattr
 #define __NR_ia32_mq_getsetattr 282
 #endif
@@ -781,10 +1000,10 @@
 #endif
 #ifndef __NR_ia32_munlock
 #define __NR_ia32_munlock 151
-#endif 
+#endif
 #ifndef __NR_ia32_munlockall
 #define __NR_ia32_munlockall 153
-#endif 
+#endif
 #ifndef __NR_ia32_munmap
 #define __NR_ia32_munmap 91
 #endif
@@ -842,6 +1061,15 @@
 #ifndef __NR_ia32_pivot_root
 #define __NR_ia32_pivot_root 217
 #endif
+#ifndef __NR_ia32_pkey_alloc
+#define __NR_ia32_pkey_alloc 381
+#endif
+#ifndef __NR_ia32_pkey_free
+#define __NR_ia32_pkey_free 382
+#endif
+#ifndef __NR_ia32_pkey_mprotect
+#define __NR_ia32_pkey_mprotect 380
+#endif
 #ifndef __NR_ia32_poll
 #define __NR_ia32_poll 168
 #endif
@@ -899,7 +1127,7 @@
 #define __NR_ia32_readdir 89
 #endif
 #ifndef __NR_ia32_readlink
-#define __NR_ia32_readlink 85 
+#define __NR_ia32_readlink 85
 #endif
 #ifndef __NR_ia32_readlinkat
 #define __NR_ia32_readlinkat 305
@@ -958,15 +1186,15 @@
 #ifndef __NR_ia32_rt_tgsigqueueinfo
 #define __NR_ia32_rt_tgsigqueueinfo 335
 #endif
-#ifndef __NR_ia32_sched_get_priority_min
-#define __NR_ia32_sched_get_priority_min 160
-#endif
 #ifndef __NR_ia32_sched_get_priority_max
 #define __NR_ia32_sched_get_priority_max 159
 #endif
+#ifndef __NR_ia32_sched_get_priority_min
+#define __NR_ia32_sched_get_priority_min 160
+#endif
 #ifndef __NR_ia32_sched_getaffinity
 #define __NR_ia32_sched_getaffinity 242
-#endif 
+#endif
 #ifndef __NR_ia32_sched_getattr
 #define __NR_ia32_sched_getattr 352
 #endif
@@ -1007,7 +1235,7 @@
 #define __NR_ia32_set_mempolicy 276
 #endif
 #ifndef __NR_ia32_set_robust_list
-#define __NR_ia32_set_robust_list 312
+#define __NR_ia32_set_robust_list 311
 #endif
 #ifndef __NR_ia32_set_tid_address
 #define __NR_ia32_set_tid_address 258
@@ -1054,6 +1282,12 @@
 #ifndef __NR_ia32_setpriority
 #define __NR_ia32_setpriority 97
 #endif
+#ifndef __NR_ia32_setregid
+#define __NR_ia32_setregid 71
+#endif
+#ifndef __NR_ia32_setregid32
+#define __NR_ia32_setregid32 204
+#endif
 #ifndef __NR_ia32_setresgid
 #define __NR_ia32_setresgid 170
 #endif
@@ -1066,12 +1300,6 @@
 #ifndef __NR_ia32_setresuid32
 #define __NR_ia32_setresuid32 208
 #endif
-#ifndef __NR_ia32_setregid
-#define __NR_ia32_setregid 71
-#endif
-#ifndef __NR_ia32_setregid32
-#define __NR_ia32_setregid32 204
-#endif
 #ifndef __NR_ia32_setreuid
 #define __NR_ia32_setreuid 70
 #endif
@@ -1093,12 +1321,12 @@
 #ifndef __NR_ia32_setuid32
 #define __NR_ia32_setuid32 213
 #endif
-#ifndef __NR_ia32_sgetmask
-#define __NR_ia32_sgetmask 68
-#endif
 #ifndef __NR_ia32_setxattr
 #define __NR_ia32_setxattr 226
 #endif
+#ifndef __NR_ia32_sgetmask
+#define __NR_ia32_sgetmask 68
+#endif
 // Since a kernel that had a 32-bit shmctl syscall can't be found
 // (they all used __NR_ipc), just use __NR_syscall_compat_max.
 #ifndef __NR_ia32_shmctl
@@ -1229,7 +1457,7 @@
 #endif
 #ifndef __NR_ia32_ugetrlimit
 #define __NR_ia32_ugetrlimit 191
-#endif 
+#endif
 #ifndef __NR_ia32_umask
 #define __NR_ia32_umask 60
 #endif
@@ -1240,7 +1468,7 @@
 #define __NR_ia32_umount2 52
 #endif
 #ifndef __NR_ia32_uname
-#define __NR_ia32_uname 109
+#define __NR_ia32_uname 122
 #endif
 #ifndef __NR_ia32_unlink
 #define __NR_ia32_unlink 10
@@ -1261,14 +1489,14 @@
 #define __NR_ia32_ustat 62
 #endif
 #ifndef __NR_ia32_utime
-#define __NR_ia32_utime 30 
+#define __NR_ia32_utime 30
 #endif
 #ifndef __NR_ia32_utimensat
 #define __NR_ia32_utimensat 320
-#endif 
+#endif
 #ifndef __NR_ia32_utimes
 #define __NR_ia32_utimes 271
-#endif 
+#endif
 #ifndef __NR_ia32_vfork
 #define __NR_ia32_vfork 190
 #endif
@@ -1302,8 +1530,8 @@
 #define __NR_compat_add_key		__NR_ia32_add_key
 #define __NR_compat_adjtimex		__NR_ia32_adjtimex
 #define __NR_compat_alarm		__NR_ia32_alarm
-#define __NR_compat_brk			__NR_ia32_brk
 #define __NR_compat_bpf			__NR_ia32_bpf
+#define __NR_compat_brk			__NR_ia32_brk
 #define __NR_compat_capget		__NR_ia32_capget
 #define __NR_compat_capset		__NR_ia32_capset
 #define __NR_compat_chdir		__NR_ia32_chdir
@@ -1312,8 +1540,8 @@
 #define __NR_compat_chown32		__NR_ia32_chown32
 #define __NR_compat_chroot		__NR_ia32_chroot
 #define __NR_compat_clock_adjtime	__NR_ia32_clock_adjtime
-#define __NR_compat_clock_gettime	__NR_ia32_clock_gettime
 #define __NR_compat_clock_getres	__NR_ia32_clock_getres
+#define __NR_compat_clock_gettime	__NR_ia32_clock_gettime
 #define __NR_compat_clock_nanosleep	__NR_ia32_clock_nanosleep
 #define __NR_compat_clock_settime	__NR_ia32_clock_settime
 #define __NR_compat_clone		__NR_ia32_clone
@@ -1336,6 +1564,7 @@
 #define __NR_compat_exit		__NR_ia32_exit
 #define __NR_compat_exit_group		__NR_ia32_exit_group
 #define __NR_compat_faccessat		__NR_ia32_faccessat
+#define __NR_compat_faccessat2		__NR_ia32_faccessat2
 #define __NR_compat_fanotify_init	__NR_ia32_fanotify_init
 #define __NR_compat_fanotify_mark	__NR_ia32_fanotify_mark
 #define __NR_compat_fchdir		__NR_ia32_fchdir
@@ -1361,8 +1590,8 @@
 #define __NR_compat_fstatfs64		__NR_ia32_fstatfs64
 #define __NR_compat_fsync		__NR_ia32_fsync
 #define __NR_compat_ftruncate		__NR_ia32_ftruncate
-#define __NR_compat_futimesat		__NR_ia32_futimesat
 #define __NR_compat_futex		__NR_ia32_futex
+#define __NR_compat_futimesat		__NR_ia32_futimesat
 #define __NR_compat_get_mempolicy	__NR_ia32_get_mempolicy
 #define __NR_compat_get_robust_list	__NR_ia32_get_robust_list
 #define __NR_compat_getcpu		__NR_ia32_getcpu
@@ -1432,6 +1661,7 @@
 #define __NR_compat_mbind		__NR_ia32_mbind
 #define __NR_compat_membarrier		__NR_ia32_membarrier
 #define __NR_compat_memfd_create	__NR_ia32_memfd_create
+#define __NR_compat_memfd_secret	__NR_ia32_memfd_secret
 #define __NR_compat_migrate_pages	__NR_ia32_migrate_pages
 #define __NR_compat_mincore		__NR_ia32_mincore
 #define __NR_compat_mkdir		__NR_ia32_mkdir
@@ -1475,6 +1705,9 @@
 #define __NR_compat_pipe		__NR_ia32_pipe
 #define __NR_compat_pipe2		__NR_ia32_pipe2
 #define __NR_compat_pivot_root		__NR_ia32_pivot_root
+#define __NR_compat_pkey_alloc		__NR_ia32_pkey_alloc
+#define __NR_compat_pkey_free		__NR_ia32_pkey_free
+#define __NR_compat_pkey_mprotect	__NR_ia32_pkey_mprotect
 #define __NR_compat_poll		__NR_ia32_poll
 #define __NR_compat_ppoll		__NR_ia32_ppoll
 #define __NR_compat_prctl		__NR_ia32_prctl
@@ -1513,8 +1746,8 @@
 #define __NR_compat_rt_sigsuspend	__NR_ia32_rt_sigsuspend
 #define __NR_compat_rt_sigtimedwait	__NR_ia32_rt_sigtimedwait
 #define __NR_compat_rt_tgsigqueueinfo	__NR_ia32_rt_tgsigqueueinfo
-#define __NR_compat_sched_get_priority_min	__NR_ia32_sched_get_priority_min
 #define __NR_compat_sched_get_priority_max	__NR_ia32_sched_get_priority_max
+#define __NR_compat_sched_get_priority_min	__NR_ia32_sched_get_priority_min
 #define __NR_compat_sched_getaffinity	__NR_ia32_sched_getaffinity
 #define __NR_compat_sched_getattr	__NR_ia32_sched_getattr
 #define __NR_compat_sched_getparam	__NR_ia32_sched_getparam
@@ -1545,12 +1778,12 @@
 #define __NR_compat_setns		__NR_ia32_setns
 #define __NR_compat_setpgid		__NR_ia32_setpgid
 #define __NR_compat_setpriority		__NR_ia32_setpriority
+#define __NR_compat_setregid		__NR_ia32_setregid
+#define __NR_compat_setregid32		__NR_ia32_setregid32
 #define __NR_compat_setresgid		__NR_ia32_setresgid
 #define __NR_compat_setresgid32		__NR_ia32_setresgid32
 #define __NR_compat_setresuid		__NR_ia32_setresuid
 #define __NR_compat_setresuid32		__NR_ia32_setresuid32
-#define __NR_compat_setregid		__NR_ia32_setregid
-#define __NR_compat_setregid32		__NR_ia32_setregid32
 #define __NR_compat_setreuid		__NR_ia32_setreuid
 #define __NR_compat_setreuid32		__NR_ia32_setreuid32
 #define __NR_compat_setrlimit		__NR_ia32_setrlimit
@@ -1644,8 +1877,8 @@
 #define __NR_compat_add_key		__NR_add_key
 #define __NR_compat_adjtimex		__NR_adjtimex
 #define __NR_compat_alarm		__NR_alarm
-#define __NR_compat_brk			__NR_brk
 #define __NR_compat_bpf			__NR_bpf
+#define __NR_compat_brk			__NR_brk
 #define __NR_compat_capget		__NR_capget
 #define __NR_compat_capset		__NR_capset
 #define __NR_compat_chdir		__NR_chdir
@@ -1654,8 +1887,10 @@
 #define __NR_compat_chown32		__NR_chown32
 #define __NR_compat_chroot		__NR_chroot
 #define __NR_compat_clock_adjtime	__NR_clock_adjtime
-#define __NR_compat_clock_gettime	__NR_clock_gettime
+#if !(defined(__aarch64__) && LINUX_VERSION_CODE >= KERNEL_VERSION(5,3,0))
 #define __NR_compat_clock_getres	__NR_clock_getres
+#define __NR_compat_clock_gettime	__NR_clock_gettime
+#endif
 #define __NR_compat_clock_nanosleep	__NR_clock_nanosleep
 #define __NR_compat_clock_settime	__NR_clock_settime
 #define __NR_compat_clone		__NR_clone
@@ -1675,9 +1910,12 @@
 #define __NR_compat_eventfd2		__NR_eventfd2
 #define __NR_compat_execve		__NR_execve
 #define __NR_compat_execveat		__NR_execveat
+#if !(defined(__aarch64__) && LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0))
 #define __NR_compat_exit		__NR_exit
+#endif
 #define __NR_compat_exit_group		__NR_exit_group
 #define __NR_compat_faccessat		__NR_faccessat
+#define __NR_compat_faccessat2		__NR_faccessat2
 #define __NR_compat_fanotify_init	__NR_fanotify_init
 #define __NR_compat_fanotify_mark	__NR_fanotify_mark
 #define __NR_compat_fchdir		__NR_fchdir
@@ -1703,8 +1941,8 @@
 #define __NR_compat_fstatfs64		__NR_fstatfs64
 #define __NR_compat_fsync		__NR_fsync
 #define __NR_compat_ftruncate		__NR_ftruncate
-#define __NR_compat_futimesat		__NR_futimesat
 #define __NR_compat_futex		__NR_futex
+#define __NR_compat_futimesat		__NR_futimesat
 #define __NR_compat_get_mempolicy	__NR_get_mempolicy
 #define __NR_compat_get_robust_list	__NR_get_robust_list
 #define __NR_compat_getcpu		__NR_getcpu
@@ -1716,7 +1954,7 @@
 #define __NR_compat_geteuid		__NR_geteuid
 #define __NR_compat_geteuid32		__NR_geteuid32
 #define __NR_compat_getgid		__NR_getgid
-#define __NR_compat_getgid32		__NE_getgid32
+#define __NR_compat_getgid32		__NR_getgid32
 #define __NR_compat_getgroups		__NR_getgroups
 #define __NR_compat_getgroups32		__NR_getgroups32
 #define __NR_compat_getitimer		__NR_getitimer
@@ -1731,10 +1969,12 @@
 #define __NR_compat_getresuid		__NR_getresuid
 #define __NR_compat_getresuid32		__NR_getresuid32
 #define __NR_compat_getrlimit		__NR_getrlimit
-#define __NR_comapt_getrusage		__NR_getrusage
+#define __NR_compat_getrusage		__NR_getrusage
 #define __NR_compat_getsid		__NR_getsid
 #define __NR_compat_gettid		__NR_gettid
+#if !(defined(__aarch64__) && LINUX_VERSION_CODE >= KERNEL_VERSION(5,3,0))
 #define __NR_compat_gettimeofday	__NR_gettimeofday
+#endif
 #define __NR_compat_getuid		__NR_getuid
 #define __NR_compat_getuid32		__NR_getuid32
 #define __NR_compat_getxattr		__NR_getxattr
@@ -1756,7 +1996,7 @@
 #define __NR_compat_kcmp		__NR_kcmp
 #define __NR_compat_kexec_file_load	__NR_kexec_file_load
 #define __NR_compat_kexec_load		__NR_kexec_load
-#define __NR_compat_keyctl		__NT_keyctl
+#define __NR_compat_keyctl		__NR_keyctl
 #define __NR_compat_kill		__NR_kill
 #define __NR_compat_lchown		__NR_lchown
 #define __NR_compat_lchown32		__NR_lchown32
@@ -1774,6 +2014,7 @@
 #define __NR_compat_mbind		__NR_mbind
 #define __NR_compat_membarrier		__NR_membarrier
 #define __NR_compat_memfd_create	__NR_memfd_create
+#define __NR_compat_memfd_secret  	__NR_memfd_secret
 #define __NR_compat_migrate_pages	__NR_migrate_pages
 #define __NR_compat_mincore		__NR_mincore
 #define __NR_compat_mkdir		__NR_mkdir
@@ -1796,14 +2037,17 @@
 #define __NR_compat_mq_unlink		__NR_mq_unlink
 #define __NR_compat_mremap		__NR_mremap
 #define __NR_compat_msync		__NR_msync
-#define __NR_copmat_munlock		__NR_munlock
+#define __NR_compat_munlock		__NR_munlock
 #define __NR_compat_munlockall		__NR_munlockall
 #define __NR_compat_munmap		__NR_munmap
 #define __NR_compat_name_to_handle_at	__NR_name_to_handle_at
 #define __NR_compat_nanosleep		__NR_nanosleep
 #define __NR_compat_nfsservctl		__NR_nfsservctl
 #define __NR_compat_nice		__NR_nice
+#define __NR_compat_oldfstat		__NR_oldfstat
+#define __NR_compat_oldlstat		__NR_oldlstat
 #define __NR_compat_oldolduname		__NR_oldolduname
+#define __NR_compat_oldstat		__NR_oldstat
 #define __NR_compat_olduname		__NR_olduname
 #define __NR_compat_open		__NR_open
 #define __NR_compat_open_by_handle_at	__NR_open_by_handle_at
@@ -1814,6 +2058,9 @@
 #define __NR_compat_pipe		__NR_pipe
 #define __NR_compat_pipe2		__NR_pipe2
 #define __NR_compat_pivot_root		__NR_pivot_root
+#define __NR_compat_pkey_alloc		__NR_pkey_alloc
+#define __NR_compat_pkey_free		__NR_pkey_free
+#define __NR_compat_pkey_mprotect	__NR_pkey_mprotect
 #define __NR_compat_poll		__NR_poll
 #define __NR_compat_ppoll		__NR_ppoll
 #define __NR_compat_prctl		__NR_prctl
@@ -1829,8 +2076,10 @@
 #define __NR_compat_pwrite64		__NR_pwrite64
 #define __NR_compat_pwritev		__NR_pwritev
 #define __NR_compat_pwritev2		__NR_pwritev2
-#define __NR_compat_quotactl		__NR_quoactl
+#define __NR_compat_quotactl		__NR_quotactl
+#if !(defined(__aarch64__) && LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0))
 #define __NR_compat_read		__NR_read
+#endif
 #define __NR_compat_readdir		__NR_readdir
 #define __NR_compat_readlink		__NR_readlink
 #define __NR_compat_readlinkat		__NR_readlinkat
@@ -1843,17 +2092,19 @@
 #define __NR_compat_renameat		__NR_renameat
 #define __NR_compat_renameat2		__NR_renameat2
 #define __NR_compat_request_key		__NR_request_key
+#if !(defined(__aarch64__) && LINUX_VERSION_CODE >= KERNEL_VERSION(3,17,0))
 #define __NR_compat_restart_syscall	__NR_restart_syscall
+#endif
 #define __NR_compat_rmdir		__NR_rmdir
 #define __NR_compat_rt_sigaction	__NR_rt_sigaction
 #define __NR_compat_rt_sigpending	__NR_rt_sigpending
 #define __NR_compat_rt_sigprocmask	__NR_rt_sigprocmask
-#define __NR_compat_rt_sigqueue		__NR_rt_sigqueue
+#define __NR_compat_rt_sigqueueinfo	__NR_rt_sigqueueinfo
 #define __NR_compat_rt_sigsuspend	__NR_rt_sigsuspend
 #define __NR_compat_rt_sigtimedwait	__NR_rt_sigtimedwait
 #define __NR_compat_rt_tgsigqueueinfo	__NR_rt_tgsigqueueinfo
-#define __NR_compat_sched_get_priority_min	__NR_sched_get_priority_min
 #define __NR_compat_sched_get_priority_max	__NR_sched_get_priority_max
+#define __NR_compat_sched_get_priority_min	__NR_sched_get_priority_min
 #define __NR_compat_sched_getaffinity	__NR_sched_getaffinity
 #define __NR_compat_sched_getattr	__NR_sched_getattr
 #define __NR_compat_sched_getparam	__NR_sched_getparam
@@ -1884,19 +2135,19 @@
 #define __NR_compat_setns		__NR_setns
 #define __NR_compat_setpgid		__NR_setpgid
 #define __NR_compat_setpriority		__NR_setpriority
+#define __NR_compat_setregid		__NR_setregid
+#define __NR_compat_setregid32		__NR_setregid32
 #define __NR_compat_setresgid		__NR_setresgid
 #define __NR_compat_setresgid32		__NR_setresgid32
 #define __NR_compat_setresuid		__NR_setresuid
 #define __NR_compat_setresuid32		__NR_setresuid32
-#define __NR_compat_setregid		__NR_setregid
-#define __NR_compat_setregid32		__NR_setregid32
 #define __NR_compat_setreuid		__NR_setreuid
-#define __NR_comapt_setreuid32		__NR_setreuid32
+#define __NR_compat_setreuid32		__NR_setreuid32
 #define __NR_compat_setrlimit		__NR_setrlimit
 #define __NR_compat_setsid		__NR_setsid
 #define __NR_compat_settimeofday	__NR_settimeofday
 #define __NR_compat_setuid		__NR_setuid
-#define __NR_compat_setuid16		__NR_setuid16
+#define __NR_compat_setuid32		__NR_setuid32
 #define __NR_compat_setxattr		__NR_setxattr
 #define __NR_compat_sgetmask		__NR_sgetmask
 #define __NR_compat_shmctl		__NR_shmctl
@@ -1943,7 +2194,7 @@
 #define __NR_compat_truncate		__NR_truncate
 #define __NR_compat_ugetrlimit		__NR_ugetrlimit
 #define __NR_compat_umask		__NR_umask
-#define __NR_comapt_umount		__NR_umount
+#define __NR_compat_umount		__NR_umount
 #define __NR_compat_umount2		__NR_umount2
 #define __NR_compat_uname		__NR_uname
 #define __NR_compat_unlink		__NR_unlink
@@ -1961,7 +2212,9 @@
 #define __NR_compat_wait4		__NR_wait4
 #define __NR_compat_waitid		__NR_waitid
 #define __NR_compat_waitpid		__NR_waitpid
+#if !(defined(__aarch64__) && LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0))
 #define __NR_compat_write		__NR_write
+#endif
 #define __NR_compat_writev		__NR_writev
 
 #endif	/* __powerpc64__ || __s390x__ || __aarch64__ */
