@@ -15,9 +15,13 @@
 
 static void _stp_hrtimer_init(void)
 {
+#if defined(STAPCONF_HRTIMER_GET_RES)
 	struct timespec res;
 	hrtimer_get_res (CLOCK_MONOTONIC, &res);
 	stap_hrtimer_resolution = timespec_to_ns(&res);
+#else
+	stap_hrtimer_resolution = hrtimer_resolution;
+#endif
 }
 
 
@@ -70,8 +74,8 @@ static int
 _stp_hrtimer_create(struct stap_hrtimer_probe *stp,
 		    hrtimer_return_t (*function)(struct hrtimer *))
 {
-	hrtimer_init(&stp->hrtimer, CLOCK_MONOTONIC, HRTIMER_MODE_REL);
-	stp->hrtimer.function = function;
+	STP_HRTIMER_SETUP(&stp->hrtimer, function,
+			  CLOCK_MONOTONIC, HRTIMER_MODE_REL);
 	return 0;
 }
 
