@@ -1,6 +1,6 @@
 /* -*- linux-c -*- 
  * Map Header File
- * Copyright (C) 2005, 2012 Red Hat Inc.
+ * Copyright (C) 2005-2016 Red Hat Inc.
  *
  * This file is part of systemtap, and is free software.  You can
  * redistribute it and/or modify it under the terms of the GNU General
@@ -19,6 +19,21 @@
 #include "dyninst/map_list.h"
 #endif
 
+/* Number of bits to add-to or subtract-from "natural" hash table size.
+   0  = natural hash table size = ilog2(max-table-elements)
+   +1 = double of natural hash table size: saves time, spends space
+   -1 = half of natural hash table size: saves space, spends time
+   -many = minimum hash table size (1 entry)
+   +many = build failure
+*/
+#ifndef MAPHASHBIAS
+#define MAPHASHBIAS 0
+#endif
+
+#define HASHTABLESIZE(entries) (1 << max_t(int, ilog2(entries)+MAPHASHBIAS, 1))
+/* NB: a power of two, since we truncate hv with & rather than % */
+
+
 /** @file map.h
  * @brief Header file for maps and lists 
  */
@@ -27,14 +42,6 @@
  * @{
  */
 
-/* This sets the size of the hash table. */
-#ifndef HASH_TABLE_BITS
-#define HASH_TABLE_BITS (ilog2(MAXMAPENTRIES)+1)
-
-/* This sets the size of the hash table. */
-#define HASH_TABLE_SIZE (1<<HASH_TABLE_BITS)
-#endif
-
 /** Maximum length of strings in maps. This sets the amount of space
     reserved for each string.  This should match MAXSTRINGLEN.  If
     MAP_STRING_LENGTH is less than MAXSTRINGLEN, a user could get
@@ -76,14 +83,20 @@ struct map_node {
  */
 struct map_root {
         /* maximum number of elements allowed in the array. */
-	int maxnum;
+	unsigned maxnum;
 
 	/* current number of used elements */
-	int num;
+	unsigned num;
 
 	/* when more than maxnum elements, wrap or discard? */
 	int wrap;
 
+        /* scale factor for integer arithmetic */
+        int bit_shift;
+
+	/* related statistical operators */
+	int stat_ops;
+
 #ifdef __KERNEL__
 	void *node_mem;
 #endif
@@ -94,19 +107,13 @@ struct map_root {
 	/* pool of unused entries. */
 	struct mlist_head pool;
 
-#ifdef NEED_MAP_LOCKS
-#ifdef __KERNEL__
-	spinlock_t lock;
-#else  /* !__KERNEL__ */
-	pthread_mutex_t lock;
-#endif
-#endif
-
-	/* the hash table for this array */
-	struct mhlist_head hashes[HASH_TABLE_SIZE];
-
 	/* used if this map's nodes contain stats */
 	struct _Hist hist;
+
+	/* the hash table for this array */
+        unsigned hash_table_mask;
+        /* dynamically allocated at tail */
+        struct mhlist_head hashes[] __counted_by(maxnum);
 };
 
 /** All maps are of this type. */
@@ -145,11 +152,9 @@ typedef int (*map_cmp_fn)(struct map_node *dst, struct map_node *src);
 /************* prototypes for map.c ****************/
 
 static int int64_eq_p(int64_t key1, int64_t key2);
-static unsigned int int64_hash(const int64_t v);
 static void str_copy(char *dest, char *src);
 static void str_add(void *dest, char *val);
 static int str_eq_p(char *key1, char *key2);
-static unsigned int str_hash(const char *key1);
 static MAP _stp_map_new(unsigned max_entries, int wrap, int node_size, int cpu);
 static PMAP _stp_pmap_new(unsigned max_entries, int wrap, int node_size);
 static MAP _stp_map_new_hstat(unsigned max_entries, int wrap, int node_size);
@@ -175,7 +180,7 @@ static void _stp_pmap_del(PMAP pmap);
 static MAP _stp_pmap_agg (PMAP pmap, map_update_fn update, map_cmp_fn cmp);
 static struct map_node *_stp_new_agg(MAP agg, struct mhlist_head *ahead,
 				     struct map_node *ptr, map_update_fn update);
-static int _new_map_set_stat (MAP map, struct stat_data *dst, int64_t val, int add);
+static int _new_map_set_stat (MAP map, struct stat_data *dst, int64_t val, int add, int s1, int s2, int s3, int s4, int s5);
 static int _new_map_copy_stat (MAP map, struct stat_data *dst, struct stat_data *src, int add);
 static void _stp_map_sort (MAP map, int keynum, int dir, map_get_key_fn get_key);
 static void _stp_map_sortn(MAP map, int n, int keynum, int dir, map_get_key_fn get_key);
