@@ -34,11 +34,6 @@ static int64_t _stp_gettimeofday_ns(void) {
 #if defined (__i386__) || defined (__x86_64__)
 #include <asm/cpufeature.h>
 #endif
-#if defined (STAPCONF_TSC_KHZ) && \
-    !(defined (__x86_64__) && LINUX_VERSION_CODE < KERNEL_VERSION(2,6,21))
-// x86_64 didn't need a specific header until 2.6.21.  Otherwise:
-#include <asm/tsc.h>
-#endif
 #ifdef STAPCONF_KTIME_GET_REAL
 #include <linux/ktime.h>
 #endif
