@@ -26,6 +26,7 @@ static void _stp_handle_tzinfo (struct _stp_msg_tzinfo* tzi);
 static void _stp_handle_privilege_credentials (struct _stp_msg_privilege_credentials* pc);
 static void _stp_handle_remote_id (struct _stp_msg_remote_id* rem);
 static void _stp_handle_namespaces_pid (struct _stp_msg_ns_pid *nspid);
+static void _stp_handle_mnt_ns_fds (struct _stp_msg_mnt_ns_fds *nsfds);
 
 
 static ssize_t _stp_ctl_write_cmd(struct file *file, const char __user *buf, size_t count, loff_t *ppos)
@@ -57,7 +58,7 @@ static ssize_t _stp_ctl_write_cmd(struct file *file, const char __user *buf, siz
 
 #if defined(DEBUG_TRANS) && (DEBUG_TRANS >= 2)
 	if (type < STP_MAX_CMD)
-		dbug_trans2("Got %s. euid=%ld, len=%d\n", _stp_command_name[min(type,STP_MAX_CMD)] ?: "?",
+		dbug_trans2("Got %s. euid=%ld, len=%d\n", _stp_command_name[min(type, (u32)STP_MAX_CMD)] ?: "?",
 			    (long)euid, (int)count);
 #endif
 
@@ -195,6 +196,22 @@ static ssize_t _stp_ctl_write_cmd(struct file *file, const char __user *buf, siz
     }
     break;
 
+        case STP_MNT_NS_FDS:
+        {
+		static struct _stp_msg_mnt_ns_fds nsfds;
+		if (count < sizeof(nsfds)) {
+			rc = 0;
+			goto out;
+		}
+		if (copy_from_user(&nsfds, buf, sizeof(nsfds))) {
+			rc = -EFAULT;
+			goto out;
+		}
+
+		_stp_handle_mnt_ns_fds(&nsfds);
+        }
+        break;
+
 	default:
 #ifdef DEBUG_TRANS
 		dbug_trans2("invalid command type %d\n", type);
@@ -212,7 +229,7 @@ out:
 #if defined(DEBUG_TRANS) && (DEBUG_TRANS >= 2)
 	if (type < STP_MAX_CMD)
 		dbug_trans2("Completed %s (rc=%d)\n",
-                            _stp_command_name[min(type,STP_MAX_CMD)] ?: "?",
+                            _stp_command_name[min(type, (u32)STP_MAX_CMD)] ?: "?",
                             rc);
 #endif
         return rc;
@@ -418,7 +435,7 @@ static void _stp_ctl_free_special_buffers(void)
 static struct _stp_buffer *_stp_ctl_get_buffer(int type, const char *data,
 					       unsigned len)
 {
-	unsigned long flags;
+	unsigned long flags = 0;
 	struct _stp_buffer *bptr = NULL;
 
 	/* Is it a dynamically allocated message type? */
@@ -481,12 +498,12 @@ static struct _stp_buffer *_stp_ctl_get_buffer(int type, const char *data,
 		}
 		if (bptr != NULL) {
 			/* OK, it is a special one, but is it free?  */
-			stp_spin_lock_irqsave(&_stp_ctl_special_msg_lock, flags);
+			stp_nmi_spin_lock_irqsave(&_stp_ctl_special_msg_lock, flags, failed);
 			if (bptr->type == _STP_CTL_MSG_UNUSED)
 				bptr->type = type;
 			else
 				bptr = NULL;
-			stp_spin_unlock_irqrestore(&_stp_ctl_special_msg_lock, flags);
+			stp_nmi_spin_unlock_irqrestore(&_stp_ctl_special_msg_lock, flags);
 		}
 
 		/* Got a special message buffer, with type set, fill it in,
@@ -501,6 +518,9 @@ static struct _stp_buffer *_stp_ctl_get_buffer(int type, const char *data,
 		}
 	}
 	return bptr;
+
+failed:
+	return NULL;
 }
 
 /* Returns the given buffer to the pool when dynamically allocated.
@@ -535,7 +555,7 @@ static int _stp_ctl_send(int type, void *data, unsigned len)
 {
 	struct context* __restrict__ c = NULL;
 	struct _stp_buffer *bptr;
-	unsigned long flags;
+	unsigned long flags = 0;
 	unsigned hlen;
 
 #ifdef DEBUG_TRANS
@@ -567,22 +587,23 @@ static int _stp_ctl_send(int type, void *data, unsigned len)
 	   skipped rather than deadlock.  */
 	c = _stp_runtime_entryfn_get_context();
 
+	stp_nmi_spin_lock_irqsave(&_stp_ctl_ready_lock, flags, no_lock);
+
 	/* get a buffer from the free pool */
 	bptr = _stp_ctl_get_buffer(type, data, len);
 	if (unlikely(bptr == NULL)) {
 		/* Nothing else we can do... but let's not spam the kernel
                    with these reports. */
                 /* printk(KERN_ERR "ctl_write_msg type=%d len=%d ENOMEM\n", type, len); */
-		_stp_runtime_entryfn_put_context(c);
-		return -ENOMEM;
+		goto no_mem;
 	}
 
 	/* Put it on the pool of ready buffers.  It's possible to recursively
 	   hit a probe here, like a kprobe in NMI or the lock tracepoints, but
 	   they will be squashed since we're holding the context busy.  */
-	stp_spin_lock_irqsave(&_stp_ctl_ready_lock, flags);
 	list_add_tail(&bptr->list, &_stp_ctl_ready_q);
-	stp_spin_unlock_irqrestore(&_stp_ctl_ready_lock, flags);
+
+	stp_nmi_spin_unlock_irqrestore(&_stp_ctl_ready_lock, flags);
 
 	_stp_runtime_entryfn_put_context(c);
 
@@ -590,6 +611,15 @@ static int _stp_ctl_send(int type, void *data, unsigned len)
 	   timer at this point, but calling mod_timer() at this
 	   point would bring in more locking issues... */
 	return len + sizeof(bptr->type);
+
+no_lock:
+	_stp_runtime_entryfn_put_context(c);
+	return -EBUSY;
+
+no_mem:
+	stp_nmi_spin_unlock_irqrestore(&_stp_ctl_ready_lock, flags);
+	_stp_runtime_entryfn_put_context(c);
+	return -ENOMEM;
 }
 
 /* Logs a warning or error through the control channel. This function mimics
@@ -603,12 +633,15 @@ static void _stp_ctl_log_werr(const char *logtype, size_t logtype_len,
 {
 	struct context *__restrict__ c;
 	struct _stp_buffer *bptr;
-	unsigned long flags;
+	unsigned long flags = 0;
 
 	c = _stp_runtime_entryfn_get_context();
+
+	stp_nmi_spin_lock_irqsave(&_stp_ctl_ready_lock, flags, put_context);
+
 	bptr = _stp_ctl_get_buffer(STP_OOB_DATA, logtype, logtype_len);
 	if (!bptr)
-		goto put_context;
+		goto unlock;
 
 	/*
 	 * This is a generic failure message for when there's no space left. We
@@ -634,9 +667,11 @@ static void _stp_ctl_log_werr(const char *logtype, size_t logtype_len,
 		bptr->buf[bptr->len++] = '\n';
 
 send_msg:
-	stp_spin_lock_irqsave(&_stp_ctl_ready_lock, flags);
 	list_add_tail(&bptr->list, &_stp_ctl_ready_q);
-	stp_spin_unlock_irqrestore(&_stp_ctl_ready_lock, flags);
+
+unlock:
+	stp_nmi_spin_unlock_irqrestore(&_stp_ctl_ready_lock, flags);
+
 put_context:
 	_stp_runtime_entryfn_put_context(c);
 }
