@@ -527,7 +527,7 @@ static int processCFI(const u8 *start, const u8 *end, unsigned long targetLoc,
 					REG_STATE.cfa.reg = value;
 					dbug_unwind(1, "DW_CFA_def_cfa reg=%ld\n", REG_STATE.cfa.reg);
 				}
-				/* fallthrough */
+				fallthrough;
 			case DW_CFA_def_cfa_offset:
 				if (REG_STATE.cfa_is_expr != 0) {
 					_stp_warn("Unexpected DW_CFA_def_cfa_offset\n");
@@ -549,7 +549,7 @@ static int processCFI(const u8 *start, const u8 *end, unsigned long targetLoc,
 						    value, DWARF_REG_MAP(value));
 					REG_STATE.cfa.reg = value;
 				}
-				/* fallthrough */
+				fallthrough;
 			case DW_CFA_def_cfa_offset_sf:
 				if (REG_STATE.cfa_is_expr != 0) {
 					_stp_warn("Unexpected DW_CFA_def_cfa_offset_sf\n");
@@ -922,7 +922,7 @@ static int compute_expr(const u8 *expr, struct unwind_frame_info *frame,
 		case DW_OP_bra:
 			if (POP == 0)
 				break;
-			/* Fall through.  */
+                        fallthrough;
 		case DW_OP_skip:
 			NEED(sizeof(u.s16));
 			memcpy(&u.s16, expr, sizeof(u.s16));
@@ -1120,7 +1120,7 @@ static int compute_expr(const u8 *expr, struct unwind_frame_info *frame,
 				switch (value) {
 #define CASE(n)     		case sizeof(u##n):			\
 					if (unlikely(_stp_deref_nofault(value, sizeof(u##n), (u##n *)addr, \
-									(user ? USER_DS : KERNEL_DS)))) \
+									(user ? STP_USER_DS : STP_KERNEL_DS)))) \
 						goto copy_failed;	\
 					break
 					CASES;
@@ -1129,6 +1129,7 @@ static int compute_expr(const u8 *expr, struct unwind_frame_info *frame,
 					goto bad_deref_size;
 				}
 			}
+		        PUSH(value);
 			break;
 
 		case DW_OP_rot:
@@ -1440,7 +1441,7 @@ static int unwind_frame(struct unwind_context *context,
 			switch (reg_info[i].width) {
 #define CASE(n)     case sizeof(u##n):					\
 				if (unlikely(_stp_deref_nofault(FRAME_REG(i, u##n), sizeof(u##n), (u##n *)addr, \
-								(user ? USER_DS : KERNEL_DS)))) \
+								(user ? STP_USER_DS : STP_KERNEL_DS)))) \
 					goto copy_failed;		\
 				if (compat_task) FRAME_REG(i, u##n) &= 0xFFFFFFFF; \
 				dbug_unwind(1, "set register %d to %lx\n", i, (long)FRAME_REG(i,u##n)); \
@@ -1494,7 +1495,7 @@ static int unwind(struct unwind_context *context, int user)
 
 	if (user)
 	  {
-	    m = _stp_umod_lookup (pc, current, & module_name, NULL, NULL);
+	    m = _stp_umod_lookup (pc, current, & module_name, NULL, NULL, NULL);
 	    if (m)
 	      s = &m->sections[0];
 	  }
