@@ -44,7 +44,7 @@
 #include <sys/wait.h>
 #include <pwd.h>
 #include "bpfinterp.h"
-#include "../util.h"
+#include "../staputil.h"
 
 extern "C" {
 #include <linux/bpf.h>
@@ -2007,7 +2007,7 @@ procfs_write_event_loop (procfsprobe_data* data, bpf_transport_context* uctx)
  
       std::string msg;
 
-      unsigned read_size = 1024;
+      const int read_size = 1024;
       int bytes_read;
 
       do {
@@ -2213,7 +2213,7 @@ main(int argc, char **argv)
 
       case 'V':
         printf("Systemtap BPF loader/runner (version %s, %s)\n"
-               "Copyright (C) 2016-2024 Red Hat, Inc. and others\n" // PRERELEASE
+               "Copyright (C) 2016-2025 Red Hat, Inc. and others\n" // PRERELEASE
                "This is free software; "
                "see the source for copying conditions.\n",
                VERSION, STAP_EXTENDED_VERSION);
