@@ -7,13 +7,14 @@
  * Public License (GPL); either version 2, or (at your option) any
  * later version.
  *
- * Copyright (C) 2005-2021 Red Hat Inc.
+ * Copyright (C) 2005-2023 Red Hat Inc.
  */
 
 #include "staprun.h"
 #include <sys/utsname.h>
 #include <sys/ptrace.h>
 #include <sys/select.h>
+#include <sys/syscall.h>
 #include <search.h>
 #include <wordexp.h>
 
@@ -23,31 +24,9 @@
 
 /* globals */
 int ncpus;
-static int pending_interrupts = 0;
+static volatile sig_atomic_t pending_interrupts = 0; // tells stp_main_loop to trigger STP_EXIT message to kernel
 static int target_pid_failed_p = 0;
 
-/* Setup by setup_main_signals, used by signal_thread to notify the
-   main thread of interruptable events. */
-static pthread_t main_thread;
-
-static void set_nonblocking_std_fds(void)
-{
-  int fd;
-  for (fd = 1; fd < 3; fd++) {
-    /* NB: writing to stderr/stdout blockingly in signal handler is
-     * dangerous since it may prevent the stap process from quitting
-     * gracefully on receiving SIGTERM/etc signals when the stderr/stdout
-     * write buffer is full. PR23891 */
-    int flags = fcntl(fd, F_GETFL);
-    if (flags == -1)
-      continue;
-
-    if (flags & O_NONBLOCK)
-      continue;
-
-    (void) fcntl(fd, F_SETFL, flags | O_NONBLOCK);
-  }
-}
 
 static void set_blocking_std_fds(void)
 {
@@ -77,43 +56,16 @@ static void my_exit(int rc)
   _exit(rc);
 }
 
-static void *signal_thread(void *arg)
-{
-  sigset_t *s = (sigset_t *) arg;
-  int signum = 0;
 
-  while (1) {
-    if (sigwait(s, &signum) < 0) {
-      _perr("sigwait");
-      continue;
-    }
+
+static void interrupt_handler(int signum)
+{
     if (signum == SIGQUIT) {
       load_only = 1; /* flag for stp_main_loop */
-      pending_interrupts ++;
-    } else if (signum == SIGINT || signum == SIGHUP || signum == SIGTERM
-               || signum == SIGPIPE)
-    {
-      pending_interrupts ++;
     }
-    if (pending_interrupts > 2) {
-      set_nonblocking_std_fds();
-      pthread_kill (main_thread, SIGURG);
-    }
-    dbug(2, "sigproc %d (%s)\n", signum, strsignal(signum));
-  }
-  /* Notify main thread (interrupts select). */
-  pthread_kill (main_thread, SIGURG);
-  return NULL;
+    pending_interrupts ++;
 }
 
-static void urg_proc(int signum)
-{
-  /* This handler is just notified from the signal_thread
-     whenever an interruptable condition is detected. The
-     handler itself doesn't do anything. But this will
-     result select to detect an EINTR event. */
-  dbug(2, "urg_proc %d (%s)\n", signum, strsignal(signum));
-}
 
 static void chld_proc(int signum)
 {
@@ -143,9 +95,9 @@ static void chld_proc(int signum)
   (void) rc; /* XXX: notused */
 }
 
+
 static void setup_main_signals(void)
 {
-  pthread_t tid;
   struct sigaction sa;
   sigset_t *s = malloc(sizeof(*s));
   if (!s) {
@@ -153,25 +105,11 @@ static void setup_main_signals(void)
     exit(1);
   }
 
-  /* The main thread will only handle SIGCHLD and SIGURG.
-     SIGURG is send from the signal thread in case the interrupt
-     flag is set. This will then interrupt any select call. */
-  main_thread = pthread_self();
-  sigfillset(s);
-  pthread_sigmask(SIG_SETMASK, s, NULL);
-
   memset(&sa, 0, sizeof(sa));
   /* select will report EINTR even when SA_RESTART is set. */
   sa.sa_flags = SA_RESTART;
   sigfillset(&sa.sa_mask);
 
-  /* Ignore all these events on the main thread. */
-  sa.sa_handler = SIG_IGN;
-  sigaction(SIGINT, &sa, NULL);
-  sigaction(SIGTERM, &sa, NULL);
-  sigaction(SIGHUP, &sa, NULL);
-  sigaction(SIGQUIT, &sa, NULL);
-
   /* This is to notify when our child process (-c) ends. */
   sa.sa_handler = chld_proc;
   sigaction(SIGCHLD, &sa, NULL);
@@ -182,26 +120,21 @@ static void setup_main_signals(void)
       sigaction(SIGWINCH, &sa, NULL);
     }
 
-  /* This signal handler is notified from the signal_thread
-     whenever a interruptable event is detected. It will
-     result in an EINTR event for select or sleep. */
-  sa.sa_handler = urg_proc;
-  sigaction(SIGURG, &sa, NULL);
+  // listen to these signals via general interrupt handler in whatever thread
+  memset(&sa, 0, sizeof(sa));
+  sa.sa_flags = SA_RESTART;
+  sigfillset(&sa.sa_mask);
 
-  /* Everything else is handled on a special signal_thread. */
-  sigemptyset(s);
-  sigaddset(s, SIGINT);
-  sigaddset(s, SIGTERM);
-  sigaddset(s, SIGHUP);
-  sigaddset(s, SIGQUIT);
-  sigaddset(s, SIGPIPE);
-  pthread_sigmask(SIG_SETMASK, s, NULL);
-  if (pthread_create(&tid, NULL, signal_thread, s) < 0) {
-    _perr(_("failed to create thread"));
-    exit(1);
-  }
+  sa.sa_handler = interrupt_handler;
+  sigaction(SIGINT, &sa, NULL);
+  sigaction(SIGTERM, &sa, NULL);
+  sigaction(SIGHUP, &sa, NULL);
+  sigaction(SIGQUIT, &sa, NULL);
+
+  // Formerly, we had a signal catching thread.
 }
 
+
 /**
  * system_cmd() executes system commands in response
  * to an STP_SYSTEM message from the module. These
@@ -391,6 +324,16 @@ void cleanup_and_exit(int detach, int rc)
   sa.sa_handler = SIG_DFL;
   sigaction(SIGCHLD, &sa, NULL);
 
+  if (target_mnt_ns_fd > 0) {
+    if (close(target_mnt_ns_fd) != 0) {
+      perror("close(target_mnt_ns_fd) failed");
+      /* nonfatal */
+    } else
+      target_mnt_ns_fd = -1;
+  }
+
+  dbug(2, "forking\n");
+
   pid = fork();
   if (pid < 0) {
           _perr("fork");
@@ -406,6 +349,30 @@ void cleanup_and_exit(int detach, int rc)
                             color_mode == color_always ? "always"
                               : color_mode == color_auto ? "auto" : "never",
                             modname);
+
+          if (orig_mnt_ns_fd > 0) {
+            /* Make sure we switch back to the orignal mount namespace
+             * just in case the kernel module switches to a different
+             * one.
+             * Also, this must be done in the new child process since
+             * the parent process is multi-threaded. */
+
+#ifdef __NR_setns
+            dbug(2, "restoring the orignal mount namespace\n");
+
+            if (syscall(__NR_setns, orig_mnt_ns_fd, CLONE_NEWNS) == -1) {
+              perror("setns(orig_mnt_ns_fd) failed");
+              /* nonfatal; just the best effort */
+            }
+#endif
+
+            if (close(orig_mnt_ns_fd) != 0) {
+              perror("close(orig_mnt_ns_fd) failed");
+              /* nonfatal */
+            } else
+              orig_mnt_ns_fd = -1;
+          }
+
           if (rc >= 1) {
                   execlp("sh", "sh", "-c", cmd, NULL);
                   /* should not return */
@@ -417,6 +384,14 @@ void cleanup_and_exit(int detach, int rc)
           }
   }
 
+  if (orig_mnt_ns_fd > 0) {
+    if (close(orig_mnt_ns_fd) != 0) {
+      perror("close(orig_mnt_ns_fd) failed");
+      /* nonfatal */
+    } else
+      orig_mnt_ns_fd = -1;
+  }
+
   /* parent process */
   if (waitpid(pid, &rstatus, 0) < 0) {
           _perr("waitpid");
@@ -451,6 +426,7 @@ int stp_main_loop(void)
       struct _stp_msg_start start;
       struct _stp_msg_cmd cmd;
       struct _stp_msg_ns_pid nspid;
+      struct _stp_msg_mnt_ns_fds nsfds;
     } payload;
   } recvbuf;
   int error_detected = 0;
@@ -688,7 +664,7 @@ int stp_main_loop(void)
       {
         struct _stp_msg_start *t = &recvbuf.payload.start;
         dbug(2, "systemtap_module_init() returned %d\n", t->res);
-        if (t->res < 0) {
+        if (t->res) {
           if (target_cmd)
             kill(target_pid, SIGKILL);
           cleanup_and_exit(0, 1);
@@ -714,21 +690,70 @@ int stp_main_loop(void)
         dbug(2, "STP_NAMESPACES_PID: %d\n", nspid->target);
         break;
       }
+    case STP_MNT_NS_FDS:
+      {
+        struct _stp_msg_mnt_ns_fds *nsfds = &recvbuf.payload.nsfds;
+        dbug(2, "STP_MNT_NS_FDS: target=%d orig=%d\n", nsfds->target_fd, nsfds->orig_fd);
+        break;
+      }
     case STP_TRANSPORT:
       {
         struct _stp_msg_start ts;
         struct _stp_msg_ns_pid nspid;
+        struct _stp_msg_mnt_ns_fds nsfds;
         if (init_relayfs() < 0) {
                 cleanup_and_exit(0, 1);
                 /* NOTREACHED */
         }
 
         if (target_namespaces_pid > 0) {
+          char buf[sizeof("/proc/4194304/ns/mnt")];
+          int fd;
+
           nspid.target = target_namespaces_pid;
+
           rc = send_request(STP_NAMESPACES_PID, &nspid, sizeof(nspid));
           if (rc != 0) {
 	    perror ("Unable to send STP_NAMESPACES_PID");
-	    cleanup_and_exit (1, rc);
+	    cleanup_and_exit (0, rc);
+	    /* NOTREACHED */
+	  }
+
+          if (snprintf_chk(buf, sizeof(buf), "/proc/%d/ns/mnt", target_namespaces_pid) != 0) {
+            perror ("Unable to construct the /proc/PID/ns/mnt file path");
+            cleanup_and_exit (0, rc);
+	    /* NOTREACHED */
+          }
+
+          fd = open(buf, O_RDONLY);
+          if (fd == -1) {
+            fprintf (stderr, "Failed to open file '%s': %s\n", buf,
+                     strerror(errno));
+            cleanup_and_exit (0, 1);
+	    /* NOTREACHED */
+          }
+
+          nsfds.target_fd = fd;
+          target_mnt_ns_fd = fd;
+
+          fd = open("/proc/self/ns/mnt", O_RDONLY);
+          if (fd == -1) {
+            close(nsfds.target_fd);
+            fprintf (stderr, "Failed to open file '%s': %s\n", buf,
+                     strerror(errno));
+            cleanup_and_exit (0, 1);
+	    /* NOTREACHED */
+          }
+
+          nsfds.orig_fd = fd;
+          orig_mnt_ns_fd = fd;
+
+          /* We will keep the fds open until cleanup_and_exit() is called. */
+
+          rc = send_request(STP_MNT_NS_FDS, &nsfds, sizeof(nsfds));
+          if (rc != 0) {
+	    perror ("Unable to send STP_MNT_NS_FDS");
+	    cleanup_and_exit (0, rc);
 	    /* NOTREACHED */
 	  }
         }
