@@ -123,6 +123,8 @@ struct pollfd pfds[3];
 
 static unsigned prefix_data = 0;
 static unsigned verbose = 0;
+static unsigned dyninst = 0;
+static unsigned bpf = 0;
 
 struct stapsh_option {
   const char* name;
@@ -132,6 +134,8 @@ struct stapsh_option {
 static const struct stapsh_option options[] = {
   { "verbose", &verbose },
   { "data", &prefix_data },
+  { "dyninst", &dyninst },
+  { "bpf", &bpf },
 };
 static const unsigned noptions = sizeof(options) / sizeof(*options);
 
@@ -425,9 +429,20 @@ do_file()
   if (!name)
     return reply ("ERROR: Missing file name\n");
   for (arg = name; *arg; ++arg)
-    if (!isalnum(*arg) &&
-        !(arg > name && (*arg == '.' || *arg == '_')))
-      return reply ("ERROR: Bad character '%c' in file name\n", *arg);
+    {
+      if (dyninst && *arg != 's')
+        dyninst--;
+      if (bpf && *arg != 'b')
+        bpf--;
+      if (*arg == '.')
+        {
+          dyninst += 2;
+          bpf += 2;
+        }
+      if (!isalnum(*arg) &&
+          !(arg > name && (*arg == '.' || *arg == '_')))
+        return reply ("ERROR: Bad character '%c' in file name\n", *arg);
+    }
 
   FILE* f = fopen(name, "w");
   if (!f)
@@ -558,7 +573,7 @@ spawn_staprun(char** args)
 
   if ((err = posix_spawn(&pid, args[0], &fa, NULL, args, environ)) != 0)
     {
-      reply("ERROR: Can't launch staprun: %s\n", strerror(err));
+      reply("ERROR: Can't launch stap backend: %s\n", strerror(err));
       posix_spawn_file_actions_destroy(&fa);
       return -1;
     }
@@ -574,6 +589,10 @@ do_run()
     return 1;
 
   char staprun[] = BINDIR "/staprun";
+  if (dyninst)
+    strcpy(staprun, BINDIR "/stapdyn");
+  if (bpf)
+    strcpy(staprun, BINDIR "/stapbpf");
   char* args[STAPSH_MAX_ARGS + 1] = { staprun, 0 };
   unsigned nargs = 1;
 
@@ -589,6 +608,8 @@ do_run()
       args[nargs++] = arg;
     }
 
+  dbug(1, "invoking %s\n", args[0]);
+  
   // Explicitly check execute permissions here, because posix_spawn will only
   // report that failure through a process exit code.
   if (access(staprun, X_OK) != 0)
