@@ -10,7 +10,7 @@
 #include "session.h"
 #include "tapsets.h"
 #include "translate.h"
-#include "util.h"
+#include "staputil.h"
 
 #include <cerrno>
 #include <cstdlib>
@@ -69,6 +69,10 @@ public:
   void emit_module_decls (systemtap_session& s);
   void emit_module_init (systemtap_session& s);
   void emit_module_exit (systemtap_session& s);
+
+  friend void warn_for_bpf(systemtap_session& s,
+                  mark_derived_probe_group *dpg,
+                  const std::string& kind);
 };
 
 
@@ -509,7 +513,7 @@ mark_derived_probe_group::emit_module_decls (systemtap_session& s)
   s.op->newline();
   s.op->newline() << "static void enter_marker_probe (void *probe_data, void *call_data, const char *fmt, va_list *args) {";
   s.op->newline(1) << "struct stap_marker_probe *smp = (struct stap_marker_probe *)probe_data;";
-  common_probe_entryfn_prologue (s, "STAP_SESSION_RUNNING", "smp->probe",
+  common_probe_entryfn_prologue (s, "STAP_SESSION_RUNNING", "", "smp->probe",
 				 "stp_probe_type_marker");
   s.op->newline() << "c->ips.kmark.marker_name = smp->name;";
   s.op->newline() << "c->ips.kmark.marker_format = smp->format;";
@@ -560,6 +564,21 @@ mark_derived_probe_group::emit_module_exit (systemtap_session& s)
 }
 
 
+// PR26234: Not supported by stapbpf.
+void
+warn_for_bpf(systemtap_session& s,
+             mark_derived_probe_group *dpg,
+             const std::string& kind)
+{
+  for (unsigned i=0; i<dpg->probes.size(); i++)
+    {
+      s.print_warning(_F("%s will be ignored by bpf backend",
+                         kind.c_str()),
+                      dpg->probes[i]->tok);
+    }
+}
+
+
 struct mark_builder: public derived_probe_builder
 {
 private:
@@ -657,8 +676,7 @@ mark_builder::build(systemtap_session & sess,
 	  getline(module_markers, format);
 
 	  // trim leading whitespace
-	  string::size_type notwhite = format.find_first_not_of(" \t");
-	  format.erase(0, notwhite);
+	  ltrim(format);
 
 	  // If the format is empty, make sure we add back a space
 	  // character, which is what MARK_NOARGS expands to.
