@@ -9,7 +9,7 @@
 #include "session.h"
 #include "tapsets.h"
 #include "translate.h"
-#include "util.h"
+#include "staputil.h"
 #include "config.h"
 #include "staptree.h"
 
