@@ -110,6 +110,8 @@ void register_tapset_perf(systemtap_session& sess);
 void register_tapset_utrace(systemtap_session& sess);
 void register_tapset_java(systemtap_session& sess);
 void register_tapset_python(systemtap_session& sess);
+void register_tapset_debuginfod(systemtap_session& sess);
+
 
 std::string path_remove_sysroot(const systemtap_session& sess,
 				const std::string& path);
@@ -175,6 +177,7 @@ struct exp_type_dwarf : public exp_type_details
   uintptr_t id () const { return reinterpret_cast<uintptr_t>(die.addr); }
   bool expandable() const { return true; }
   functioncall *expand(autocast_op* e, bool lvalue);
+  void print (std::ostream& o) const;
 };
 
 #endif // TAPSETS_H
