@@ -1,5 +1,5 @@
 void foo(void) {
-    asm("movl $0xbeefdead, %ebx");
+    asm("movl $0xbeefdead, %edx");
     return;
 }
 
