@@ -27,6 +27,8 @@
 #define CLONE_FLAGS (CLONE_NEWPID|CLONE_FILES|CLONE_FS|CLONE_VM|SIGCHLD)
 
 #if !defined(USE_SEMAPHORES)
+#undef TEST_CHILD2_ENABLED
+#define TEST_CHILD2_ENABLED() (1)
 #undef TEST_CHILD1_ENABLED
 #define TEST_CHILD1_ENABLED() (1)
 #undef TEST_CHILD2_PID_ENABLED
