@@ -2,6 +2,7 @@ spawn stap $srcdir/$subdir/args.stp
 expect {
     -timeout 120
     "READY" {
+	sleep 1
 	exec echo 1 > /proc/stap_test_cmd
 	expect {
 	    -timeout 5
@@ -56,4 +57,4 @@ expect {
 }
 kill -INT -[exp_pid] 2
 catch { close }
-wait
+catch { wait }
