@@ -15,10 +15,13 @@ expect {
     -timeout 120
     "<no kernel backtrace at begin>\r\n" {
 	pass "backtrace of begin probe"
+	sleep 1
 	exec echo 0 > /proc/stap_test_cmd
 	exp_continue
     }
 
+    -re {^WARNING: Missing unwind data for a module[^\r\n]*\r\n} { exp_continue }
+
     #backtrace from yyy_func2
     -re {^backtrace from module\(\"systemtap_test_module2\"\)\.function\(\"yyy_func2@[^\r\n]+\r\n} {
 	incr m1
