@@ -4,7 +4,7 @@ set host            localhost
 set port            11900
 
 proc receiver {sock addr port} {
-   fconfigure $sock -encoding binary -buffersize 16
+   fconfigure $sock -translation binary -buffersize 16
    while {[read $sock 16] != {}} { }
    exit
 }
@@ -13,7 +13,7 @@ proc sender { } {
    set tst_str      "1234567890123456"
    after 2000
    while {[catch {set sock [socket $::host $::port]}]} {}
-   fconfigure $sock -encoding binary -buffersize 16
+   fconfigure $sock -translation binary -buffersize 16
    for {set i 6400} {$i > 0} {incr i -1} {
       puts -nonewline $sock $tst_str;
    }
