@@ -7,6 +7,7 @@
 #include <sys/types.h>
 #include <sys/syscall.h>
 #include <linux/keyctl.h>
+#include <sys/mman.h>
 
 typedef int32_t key_serial_t;
 
@@ -31,6 +32,8 @@ key_serial_t __request_key(const char *type, const char *description,
 }
 
 int main() {
+    mlockall(MCL_CURRENT);
+
     key_serial_t ring_id, ring_id_2, ring_id_3, key_id, key_id_2;
 
     // --- test normal operation for keyctl manpage scenarios
@@ -45,7 +48,7 @@ int main() {
 
     // (*) Create a keyring
     ring_id_2 = __add_key("keyring", "newring2", NULL, 0, ring_id);
-    //staptest// add_key ("keyring", "newring2",\ +(null), 0, NNNN) = NNNN
+    //staptest// add_key ("keyring", "newring2",\ +0x0, 0, NNNN) = NNNN
 
     // (*) Get persistent keyring
 #ifdef KEYCTL_GET_PERSISTENT
@@ -207,23 +210,23 @@ int main() {
     __add_key((const char *)-1, (const char *)-1, (const char *)-1, -1, -1);
 #ifdef __s390__
 #if __WORDSIZE == 64
-    //staptest// add_key ([7]?[f]+, [7]?[f]+, [7]?[f]+, 18446744073709551615, -1) = NNNN (EINVAL)
+    //staptest// add_key (0x[7]?[f]+, 0x[7]?[f]+, 0x[7]?[f]+, 18446744073709551615, -1) = NNNN (EINVAL)
 #else
-    //staptest// add_key ([7]?[f]+, [7]?[f]+, [7]?[f]+, 4294967295, -1) = NNNN (EINVAL)
+    //staptest// add_key (0x[7]?[f]+, 0x[7]?[f]+, 0x[7]?[f]+, 4294967295, -1) = NNNN (EINVAL)
 #endif
 #else
 #if __WORDSIZE == 64
-    //staptest// add_key ([f]+, [f]+, [f]+, 18446744073709551615, -1) = NNNN (EINVAL)
+    //staptest// add_key (0x[f]+, 0x[f]+, 0x[f]+, 18446744073709551615, -1) = NNNN (EINVAL)
 #else
-    //staptest// add_key ([f]+, [f]+, [f]+, 4294967295, -1) = NNNN (EINVAL)
+    //staptest// add_key (0x[f]+, 0x[f]+, 0x[f]+, 4294967295, -1) = NNNN (EINVAL)
 #endif
 #endif
 
     __request_key((const char *)-1, (const char *)-1, (const char *)-1, -1);
 #ifdef __s390__
-    //staptest// request_key ([7]?[f]+, [7]?[f]+, 0x[7]?[f]+, -1) = -14 (EFAULT)
+    //staptest// request_key (0x[7]?[f]+, 0x[7]?[f]+, 0x[7]?[f]+, -1) = -14 (EFAULT)
 #else
-    //staptest// request_key ([7]?[f]+, [7]?[f]+, 0x[f]+, -1) = -14 (EFAULT)
+    //staptest// request_key (0x[7]?[f]+, 0x[7]?[f]+, 0x[f]+, -1) = -14 (EFAULT)
 #endif
 
     return 0;
