@@ -5,6 +5,7 @@
 #include <sys/types.h>
 #include <sys/quota.h>
 //#include <xfs/xqm.h>
+#include <sys/mman.h>
 
 
 #ifndef QFMT_VFS_V0
@@ -26,6 +27,8 @@ int main()
     // anyway.
     uid = getuid();
 
+    mlockall(MCL_CURRENT);
+
     quotactl(QCMD(Q_QUOTAON, USRQUOTA), "somedevice", QFMT_VFS_V0, "staptestmnt/aquota.user");
     //staptest// quotactl (Q_QUOTAON|USRQUOTA, "somedevice", QFMT_VFS_V0, "staptestmnt/aquota.user") = -NNNN
 
