@@ -9,6 +9,7 @@
 #include <linux/unistd.h>
 #include <sys/uio.h>
 #include <sys/syscall.h>
+#include <sys/mman.h>
 
 #define STRING1 "red"
 #define STRING2 "green"
@@ -19,6 +20,8 @@ int main()
   loff_t res;
   char buf[64], buf1[32], buf2[32], buf3[32];
 
+  mlockall(MCL_CURRENT);
+
   fd = open("foobar1", O_WRONLY|O_CREAT, 0666);
   //staptest// [[[[open (!!!!openat (AT_FDCWD, ]]]]"foobar1", O_WRONLY|O_CREAT[[[[.O_LARGEFILE]]]]?, 0666) = NNNN
 
